<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:ixml="http://invisiblexml.org/NS"
                version="3.0"
                default-mode="gxml"
                exclude-result-prefixes="xs"
>

  <!-- gfxml1-to-fxml: input is a generically fielded document with trial
       and field boundaries assumed correct.
       
       Task of this stylesheet:
       
       - Recognize fields by name, tag them appropriately.
       
       Everything else remains the same.
  -->
  
  <xsl:mode name="gxml" on-no-match="shallow-copy"/>
  
  <xsl:output
      indent="no"
      />

  <!--****************************************************************
      * document element
      ****************************************************************
      *-->
  <xsl:template match="/*">
    <TLRR-fielded xmlns:ixml="http://invisiblexml.org/NS">
      <xsl:apply-templates/>
    </TLRR-fielded>
    <!--
    <xsl:element name="TLRR-fielded" xmlns:ixml="http://invisiblexml.org/NS">
      <xsl:apply-templates/>
    </xsl:element>
    -->
  </xsl:template>
  
  <!--****************************************************************
      * NB (p as first child of trial)
      ****************************************************************
      *-->
  <xsl:template match="trial/*[1]/self::p">
    <xsl:element name="NB">
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>

  <!--****************************************************************
      * labeled fields
      ****************************************************************
      *-->
  <xsl:template match="field">
    <xsl:variable name="label" as="xs:string" select="label"/>
    <xsl:variable name="gi">
      <xsl:choose>
        <xsl:when test="$label = ('date', 'charge', 'claim',
                        'plaintiff', 'juror', 'outcome')">
          <xsl:sequence select="$label"/>
        </xsl:when>
        <xsl:when test="$label = ('defendant',
                        'defendants',
                        'defendants?')">
          <xsl:sequence select=" 'defendant' "/>
        </xsl:when>
        <xsl:when test='$label = ("prosecutor",
                        "prosecutors")'>
          <xsl:sequence select=' "prosecutor" '/>
        </xsl:when>
        <xsl:when test='$label = ("party",
                        "opposing party",
                        "parties")'>
          <xsl:sequence select=' "party" '/>
        </xsl:when>
        <xsl:when test='$label = ("judge",
                        "praetor",
                        "peregrine praetor",
                        "peregrine? praetor",
                        "urban praetor",
                        "(urban?) praetor",
                        "urban and peregrine praetor",
                        "judge (triumvir capitalis)",
                        "praetor or iudex quaestionis",
                        "aedile or iudex quaestionis",
                        "iudex quaestionis",
                        "duumvir perduellionis",
                        "quaesitor",
                        "quaesitores",
                        "iudices"
                        )'>
          <xsl:sequence select=' "judge" '/>          
        </xsl:when>
        <xsl:when test='$label = (
                        "advocate",
                        "advocates",
                        "advocate for defendant",
                        "advocates for defendant",
                        "advocate for defendants",
                        "advocates for defendants",
                        "advocate for plaintiff",
                        "advocates for plaintiff",
                        "advocate for plaintiffs",
                        "advocates for plaintiffs"
                        )'>
          <xsl:sequence select=' "advocate" '/>
        </xsl:when>
        <xsl:when test='$label = (
                        "witness",
                        "witnesses",
                        "cognitor",
                        "procurator"
                        )'>
          <xsl:sequence select=' "witness" '/>
        </xsl:when>
        <xsl:when test='$label = (
                        "other",
                        "legate",
                        "legates",
                        "in attendance",
                        "present for defense",
                        "present for defendants"
                        )'>
          <xsl:sequence select=' "other" '/>
        </xsl:when>
        
      </xsl:choose>
    </xsl:variable>
    
    <xsl:element name="{$gi}">
      <xsl:if test="$label ne $gi">
        <xsl:attribute name="label" select="$label"/>
      </xsl:if>
      <xsl:apply-templates select="child::node() except label"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="value">
    <xsl:apply-templates/>
  </xsl:template>

  <!-- This doesn't seem to help -->
  <xsl:template match="namespace-node()"/>
  
</xsl:stylesheet>
