<?xml version="1.0" encoding="utf-8"?>
<!-- wordml-to-ascii:  read Word file as sent by Federico and Manfredi,
     write a rudimentary XML file, with trivial markup for

     - it = italic
     - bd = bold
     - ins = insertion
     - del = deletion

     -->
<!-- Revision history:
     2024-04-24 : CMSMcQ : extend to handle WordML created from TLRR1, which
                           I expect to be the basis of the data from trial 131 on.     
     2024-04-04 : CMSMcQ : working version for Balisage submission
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                version="3.0"
                xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
                xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
                mc:Ignorable="w14 w15 w16se w16cid w16 w16cex w16sdtdh wp14"
                exclude-result-prefixes="w mc xs xsl"

>
  <!--

                xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas"
                xmlns:cx="http://schemas.microsoft.com/office/drawing/2014/chartex"
                xmlns:cx1="http://schemas.microsoft.com/office/drawing/2015/9/8/chartex"
                xmlns:cx2="http://schemas.microsoft.com/office/drawing/2015/10/21/chartex"
                xmlns:cx3="http://schemas.microsoft.com/office/drawing/2016/5/9/chartex"
                xmlns:cx4="http://schemas.microsoft.com/office/drawing/2016/5/10/chartex"
                xmlns:cx5="http://schemas.microsoft.com/office/drawing/2016/5/11/chartex"
                xmlns:cx6="http://schemas.microsoft.com/office/drawing/2016/5/12/chartex"
                xmlns:cx7="http://schemas.microsoft.com/office/drawing/2016/5/13/chartex"
                xmlns:cx8="http://schemas.microsoft.com/office/drawing/2016/5/14/chartex"
                xmlns:aink="http://schemas.microsoft.com/office/drawing/2016/ink"
                xmlns:am3d="http://schemas.microsoft.com/office/drawing/2017/model3d"
                xmlns:o="urn:schemas-microsoft-com:office:office"
                xmlns:oel="http://schemas.microsoft.com/office/2019/extlst"
                xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"
                xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math"
                xmlns:v="urn:schemas-microsoft-com:vml"
                xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing"
                xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing"
                xmlns:w10="urn:schemas-microsoft-com:office:word"      

                
                xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml"
                xmlns:w15="http://schemas.microsoft.com/office/word/2012/wordml"
                xmlns:w16cex="http://schemas.microsoft.com/office/word/2018/wordml/cex"
                xmlns:w16cid="http://schemas.microsoft.com/office/word/2016/wordml/cid"
                xmlns:w16="http://schemas.microsoft.com/office/word/2018/wordml"
                xmlns:w16sdtdh="http://schemas.microsoft.com/office/word/2020/wordml/sdtdatahash"
                xmlns:w16se="http://schemas.microsoft.com/office/word/2015/wordml/symex"
                xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup"
                xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk"
                xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml"
                xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape"

  -->

  <xsl:output
      indent="no"
      />

  <xsl:strip-space elements="*
                             w:body
                             w:p"
                   />
  <xsl:strip-space elements="w:t"
                   />

  <!-- Explicit default for namespaces other than w (do we have any?) -->
  <xsl:template match="*[not(self::w:*)]">
    <xsl:message>Element named <xsl:value-of select="name()"/> found ...</xsl:message>
    <xsl:apply-templates select="@*, child::node()"/>
  </xsl:template>
  
  <xsl:template match="@*[not(self::w:*)]">
    <xsl:message>Attribute named <xsl:value-of select="name()"/> found ...</xsl:message>
    <xsl:apply-templates/>
  </xsl:template>


  <!--****************************************************************
      * Top
      ****************************************************************
      *-->
  <xsl:template match="/">
    <xsl:element name="TLRR-rudimentary-XML">
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>

  <!--****************************************************************
      * Paragraphs
      ****************************************************************
      *-->
  
  <xsl:template match="w:p">
    <xsl:text>&#xA;</xsl:text>

    <xsl:variable name="indent-attribute" as="attribute(indent)?">
      <xsl:choose>
        <xsl:when test="exists(w:pPr/w:ind)">
          <xsl:variable name="indent" as="xs:string"
                        select="(w:pPr/w:ind/@w:left,
                                w:pPr/w:ind/@w:firstLine)[1]"/>
          <xsl:attribute name="indent" select="$indent"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:sequence select="()"/>
        </xsl:otherwise>
      </xsl:choose>      
    </xsl:variable>
    
    <xsl:choose>
      <xsl:when test="child::w:br">
        <xsl:for-each-group select="child::*"
                            group-starting-with="w:br" >
          <xsl:element name="p">
            <xsl:sequence select="$indent-attribute"/>
            <xsl:apply-templates select="current-group()"/>
          </xsl:element>
        </xsl:for-each-group>
      </xsl:when>      
      <xsl:otherwise>
        <p>
          <xsl:sequence select="$indent-attribute"/>
          <xsl:apply-templates/>
        </p>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Paragraphs -->
  <!--
  <xsl:template match="w:p[w:pPr[w:b]]">
    <p><b><xsl:apply-templates/></b></p>
    </xsl:template>
  -->

  <!-- Runs -->
  <xsl:template match="w:r[w:rPr[w:i]]">
    <i><xsl:apply-templates/></i>
  </xsl:template>

  <xsl:template match="w:r[w:rPr[w:b]]">
    <b><xsl:apply-templates/></b>
  </xsl:template>
  
  <xsl:template match="w:r[w:rPr[w:i][w:b]]"
                priority="2">
    <b><i><xsl:apply-templates/></i></b>
  </xsl:template>

  <!-- Change tracking -->
  <xsl:template match="w:ins">
    <ins><xsl:apply-templates/></ins>
  </xsl:template>
  
  <xsl:template match="w:del">
    <del><xsl:apply-templates/></del>
  </xsl:template>

  <!-- Complications in Word version of TLRR1 -->
  
  <!--* Headings are marked with named styles. *-->
  <xsl:template match="w:p[w:pPr/w:pStyle[@w:val = ('Heading2 Heading3 Heading4')]]
                       /w:r">
    <b><xsl:apply-templates/></b>
  </xsl:template>  

  <!-- Notes for downstream:
       . Trial numbers lack "No. ", they are just bolded paragraphs with numbers.
       -->
</xsl:stylesheet>
